
# Slot: repr


the name of the python object that implements this type definition

URI: [linkml:repr](https://w3id.org/linkml/repr)


## Domain and Range

type_definition &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * type_definition
